@@ -162,6 +162,12 @@ without_env <- function(f) {
 
 expect_r_process_snapshot <- function(..., interactive = TRUE, echo = TRUE,
                                       transform = NULL, variant = NULL) {
+  # Skip these tests on platforms where V8 is not available
+  if (! R.Version()$arch %in% c("i386", "x86_64", "aarch64") &&
+                   ! requireNamespace("asciicast", quietly = TRUE)) {
+    skip("No asciicast package")
+  }
+
   # errors.R assumes non-interactive in testthat, but we don't want that
   withr::local_envvar(TESTTHAT = NA_character_)
   dots <- eval(substitute(alist(...)))
